@@ -11,7 +11,7 @@ from lxml import etree
 from queue import Queue
 from enum import Enum
 
-from .utils import loadXML, XMLPath, Setting
+from .utils import load_xml, XMLPath, Setting
 
 
 logger = logging.getLogger("Renderer")
@@ -188,7 +188,7 @@ class Renderer:
         self.set_state('A_ARG_TYPE_Direction', 'Output')
         self.set_state('CurrentConnectionIDs', '0')
         self.set_state('PlaybackStorageMedium', 'None')
-        self.set_state('SinkProtocolInfo', loadXML(XMLPath.PROTOCOL_INFO.value))
+        self.set_state('SinkProtocolInfo', load_xml(XMLPath.PROTOCOL_INFO.value).strip())
 
     def add_subscribe(self, service, url, timeout=1800):
         """Add a DLNA client to subscribe list
@@ -334,6 +334,10 @@ class Renderer:
             output = self.action_list[service][action].output
             for arg in output:
                 res[arg.name] = self.state_list[arg.state].value
+        if method not in ['ConnectionManager_GetProtocolInfo', 'AVTransport_GetPositionInfo']:
+            logger.info("{}res: {}".format("*" * 20, res))
+        else:
+            logger.info("{}res: {}".format("*" * 20, method))
 
         # build response xml
         ns = 'http://schemas.xmlsoap.org/soap/envelope/'
@@ -349,7 +353,7 @@ class Renderer:
         for key in res:
             prop = etree.SubElement(response, key)
             prop.text = str(res[key])
-        return etree.tostring(root, encoding="UTF-8", xml_declaration=True)
+        return etree.tostring(root, encoding="UTF-8", xml_declaration=False)
 
     def set_state(self, name, value):
         """Set states of the render
@@ -458,13 +462,12 @@ class Renderer:
             if title_xml is not None and title_xml.text is not None:
                 title = title_xml.text
             self.set_media_title(title)
-            metadata = etree.tostring(
-                meta, encoding="UTF-8", xml_declaration=True)
+            metadata = etree.tostring(meta, encoding="UTF-8", xml_declaration=False)
         except Exception as e:
             logger.error(str(e))
             self.set_state('CurrentTrackMetaData', data['CurrentURIMetaData'].value)
         else:
-            self.set_state('CurrentTrackMetaData', metadata)
+            self.set_state('CurrentTrackMetaData', metadata.decode())
         self.set_media_resume()
         self.set_state('CurrentTrackURI', uri)
         self.set_state('RelativeTimePosition', '00:00:00')
@@ -552,8 +555,7 @@ class Renderer:
         self.set_state('CurrentMediaDuration', data)
 
     def set_state_transport(self, data):
-        """data : string in [PLAYING, PAUSED_PLAYBACK, STOPPED,
-                    NO_MEDIA_PRESENT, TRANSITIONING]
+        """data : string in [PLAYING, PAUSED_PLAYBACK, STOPPED, NO_MEDIA_PRESENT]
         """
         self.set_state('TransportState', data)
         self.set_state('TransportStatus', 'OK')
