@@ -2,7 +2,6 @@
 
 import os
 import sys
-import socket
 import uuid
 import json
 import time
@@ -31,6 +30,8 @@ class SettingProperty(Enum):
     ApplicationPort = 4
     DLNA_FriendlyName = 5
     DLNA_Renderer = 6
+    Blocked_Interfaces = 7
+    Additional_Interfaces = 8
 
 
 class Setting:
@@ -38,7 +39,6 @@ class Setting:
     version = None
     setting_path = os.path.join(SETTING_DIR, "macast_setting.json")
     last_ip = None
-    renderer_path = 'mpv'
     base_path = None
     friendly_name = "Macast({})".format(platform.node())
 
@@ -66,8 +66,12 @@ class Setting:
             if not os.path.exists(Setting.setting_path):
                 Setting.setting = {}
             else:
-                with open(Setting.setting_path, "r") as f:
-                    Setting.setting = json.load(fp=f)
+                try:
+                    with open(Setting.setting_path, "r") as f:
+                        Setting.setting = json.load(fp=f)
+                    logger.error(Setting.setting)
+                except Exception as e:
+                    logger.error(e)
         return Setting.setting
 
     @staticmethod
@@ -83,7 +87,7 @@ class Setting:
         return str(platform.system())
 
     @staticmethod
-    def getVersion():
+    def get_version():
         """Get application version
         """
         return Setting.version
@@ -94,8 +98,7 @@ class Setting:
         This name will show in the device search list of the DLNA client
         and as player window default name.
         """
-        return Setting.get(SettingProperty.DLNA_FriendlyName,
-                           Setting.friendly_name)
+        return Setting.get(SettingProperty.DLNA_FriendlyName, Setting.friendly_name)
 
     @staticmethod
     def set_friendly_name(name):
@@ -104,12 +107,13 @@ class Setting:
         and as player window default name.
         """
         Setting.friendly_name = name
+        Setting.save()
 
     @staticmethod
-    def getUSN():
+    def get_usn(refresh=False):
         """Get device Unique identification
         """
-        if 'USN' in Setting.setting:
+        if 'USN' in Setting.setting and not refresh:
             return Setting.setting['USN']
         Setting.setting['USN'] = str(uuid.uuid4())
         Setting.save()
@@ -117,20 +121,38 @@ class Setting:
 
     @staticmethod
     def is_ip_changed():
-        return Setting.last_ip != Setting.get_ip()
+        last_ip = sorted(Setting.last_ip)
+        current_ip = sorted(Setting.get_ip())
+        if last_ip != current_ip:
+            logger.error("ip: {} - {}".format(last_ip, current_ip))
+            return True
+        return False
 
     @staticmethod
     def get_ip():
         Setting.last_ip = []
-        gateways = ni.gateways()
-        interfaces = []
-        if ni.AF_INET in gateways:
-            interfaces += gateways[ni.AF_INET]
-        if ni.AF_LINK in gateways:
-            interfaces += gateways[ni.AF_LINK]
+        gateways = ni.gateways()  # {type: [{ip, interface, default},{},...], type: []}
+        interfaces = set(Setting.get(SettingProperty.Additional_Interfaces, []))
+        interface_type = [ni.AF_INET, ni.AF_LINK]
+        for t in interface_type:
+            if t in gateways:
+                for i in gateways[t]:
+                    if len(i) > 1:
+                        interfaces.add(i[1])
+        for i in Setting.get(SettingProperty.Blocked_Interfaces, []):
+            if i in interfaces:
+                interfaces.remove(i)
+        logger.debug(interfaces)
         for i in interfaces:
-            for j in ni.ifaddresses(i[1])[ni.AF_INET]:
-                Setting.last_ip.append((j['addr'], j['netmask']))
+            try:
+                iface = ni.ifaddresses(i)
+            except ValueError as e:
+                continue
+            if ni.AF_INET in iface:
+                for j in iface[ni.AF_INET]:
+                    if 'addr' in j and 'netmask' in j:
+                        Setting.last_ip.append((j['addr'], j['netmask']))
+        logger.debug(Setting.last_ip)
         return Setting.last_ip
 
     @staticmethod
@@ -160,15 +182,6 @@ class Setting:
             lang = lang.split(':')[0].split('.')[0]
         return lang
 
-    @staticmethod
-    def set_renderer_path(path):
-        """Set renderer path
-        MacOS default: bin/MacOS/mpv
-        Windows default: bin/mpv.exe
-        Others Default: mpv
-        """
-        Setting.renderer_path = path
-
     @staticmethod
     def get(property, default=1):
         """Get application settings
@@ -248,7 +261,7 @@ class Setting:
     def get_server_info():
         return '{}/{} UPnP/1.0 Macast/{}'.format(Setting.get_system(),
                                                  Setting.get_system_version(),
-                                                 Setting.getVersion())
+                                                 Setting.get_version())
 
     @staticmethod
     def get_system_env():
@@ -297,7 +310,7 @@ class XMLPath(Enum):
     PROTOCOL_INFO = BASE_PATH + '/xml/SinkProtocolInfo.csv'
 
 
-def loadXML(path):
+def load_xml(path):
     with open(path) as f:
         xml = f.read()
     return xml
